
# 1.1.2

Support Option tags 
Support access tagged options as group (tuple)
fix "Option.get_text is missed" issue.

# 1.1.1

Fix issue that `__IGNORE_INVALID_NAME__` does not work.

# 1.1.0

Change `Option` to make its instance object same as its `code`. 

# 1.0.0

General Available